@@ -392,6 +392,11 @@ int process_cmdline(int argc, char **argv)
 {
 	int i;
 
+	if (argc == 1) {
+		print_help();
+		return -1;
+	}
+
 	for (i = 1; i < argc; i++) {
 		if (strcmp(argv[i], "-dev") == 0) {
 			g_dcic_dev = atoi(argv[++i]);
@@ -424,6 +429,8 @@ int main(int argc, char **argv)
 	int retval = TPASS;
 	struct fb_var_screeninfo screen_info;
 
+	printf("\n---- Running < %s > test ----\n\n", argv[0]);
+
 	if (process_cmdline(argc, argv) < 0) {
 		return -1;
 	}
@@ -463,9 +470,10 @@ int main(int argc, char **argv)
 	g_fb0_size = screen_info.xres * screen_info.yres_virtual * screen_info.bits_per_pixel / 8;
 
 	/* Map the device to memory*/
-	fb0 = (void *)mmap(0, g_fb0_size,PROT_READ | PROT_WRITE, MAP_SHARED, fd_fb0, 0);
-	if ((int)fb0 <= 0) {
+	fb0 = mmap(0, g_fb0_size,PROT_READ | PROT_WRITE, MAP_SHARED, fd_fb0, 0);
+	if (fb0 == MAP_FAILED) {
 		printf("\nError: failed to map framebuffer device 0 to memory.\n");
+		retval = TFAIL;
 		goto err2;
 	}
 
