@@ -20,8 +20,7 @@
 #include <termios.h>
 #include <unistd.h>
 
-
-int test() {
+int test(void) {
   char buf[48];
   int fd;
 
@@ -46,8 +45,9 @@ int test() {
 }
 
 int main(int argc,char **argv) {
+  printf("\n---- Running < %s > test ----\n\n", argv[0]);
   test();
-
+  printf("\n----  Test < %s > ended  ----\n\n", argv[0]);
   return 0;
 }
 
