@@ -302,6 +302,8 @@ int main(int argc, char **argv)
 	int ret;
 	char *soc_list[] = {"i.MX6UL", " "};
 
+	printf("\n---- Running < %s > test ----\n\n", argv[0]);
+
 	ret = soc_version_check(soc_list);
 	if (ret == 0) {
 		printf("acctest.out not supported on current soc\n");
@@ -381,7 +383,7 @@ int main(int argc, char **argv)
 			if (ev[i].type == EV_SYN) {
 				printf
 				    ("Event: time %ld.%06ld, ---- %s ----\n",
-				     ev[i].time.tv_sec, ev[i].time.tv_usec,
+				     ev[i].input_event_sec, ev[i].input_event_usec,
 				     ev[i].code ? "Config Sync" :
 				     "Report Sync");
 			} else if (ev[i].type == EV_MSC
@@ -389,7 +391,7 @@ int main(int argc, char **argv)
 				       || ev[i].code == MSC_SCAN)) {
 				printf
 				    ("Event: time %ld.%06ld, type %d (%s), code %d (%s), value %02x\n",
-				     ev[i].time.tv_sec, ev[i].time.tv_usec,
+				     ev[i].input_event_sec, ev[i].input_event_usec,
 				     ev[i].type,
 				     events[ev[i].type] ?
 				     events[ev[i].type] : "?",
@@ -401,7 +403,7 @@ int main(int argc, char **argv)
 			} else {
 				printf
 				    ("Event: time %ld.%06ld, type %d (%s), code %d (%s), value %f\n",
-				     ev[i].time.tv_sec, ev[i].time.tv_usec,
+				     ev[i].input_event_sec, ev[i].input_event_usec,
 				     ev[i].type,
 				     events[ev[i].type] ?
 				     events[ev[i].type] : "?",
