@@ -22,6 +22,7 @@
 #include <errno.h>
 #include <linux/types.h>
 #include <linux/spi/spidev.h>
+#include "../../include/test_utils.h"
 
 #define BUF_MAX_SIZE	0x1000
 #define DEV_SPI1	"/dev/spidev1.4"
@@ -225,11 +226,13 @@ exit:
 
 int main(int argc, char **argv)
 {
-	int spi_id;
+	int spi_id = -1;
 	int bytes, len;
 	int res;
 	int i;
 
+	print_name(argv);
+
 	if (argc <= 1) {
 		help_info(argv[0]);
 		return 1;
@@ -240,11 +243,6 @@ int main(int argc, char **argv)
 		if(!strcmp(argv[i], "-D")) {
 			i++;
 			spi_id = atoi(argv[i]);
-			if (spi_id < 0 || spi_id > 2) {
-				printf("invalid parameter for device option\n");
-				help_info(argv[0]);
-				return -1;
-			}
 		} else if(!strcmp(argv[i], "-s")) {
 			i++;
 			speed = atoi(argv[i]);
@@ -264,6 +262,12 @@ int main(int argc, char **argv)
 		}
 	}
 
+	if (spi_id < 0 || spi_id > 2) {
+		printf("invalid parameter for device option\n");
+		help_info(argv[0]);
+		return -1;
+	}
+
 	bytes = strlen((char *)argv[argc - 1]);
 	if (bytes < 1) {
 		printf("invalid parameter for buffer size\n");
