@@ -51,6 +51,9 @@ extern "C"{
 #include "pxp_lib.h"
 #endif
 
+#include "../../include/soc_check.h"
+#include "../../include/test_utils.h"
+
 sigset_t sigset;
 int quitflag;
 
@@ -187,7 +190,7 @@ static void print_pixelformat(char *prefix, int val)
 					(val >> 24) & 0xff);
 }
 
-void vl42_device_cap_list(void)
+void v4l2_device_cap_list(void)
 {
 	struct v4l2_capability cap;
 	struct v4l2_fmtdesc fmtdesc;
@@ -258,7 +261,7 @@ int v4l_capture_setup(void)
 	if (ioctl(fd_v4l, VIDIOC_S_PARM, &parm) < 0)
 	{
 		printf("VIDIOC_S_PARM failed\n");
-		return -1;
+		goto fail;
 	}
 
 	fmtdesc.index = 0;
@@ -266,8 +269,7 @@ int v4l_capture_setup(void)
 
 	if (ioctl(fd_v4l, VIDIOC_ENUM_FMT, &fmtdesc) < 0) {
 		printf("VIDIOC ENUM FMT failed \n");
-		close(fd_v4l);
-		return -1;
+		goto fail;
 	}
 	print_pixelformat("pixelformat (output by camera)",
 			fmtdesc.pixelformat);
@@ -277,7 +279,7 @@ int v4l_capture_setup(void)
 	frmsize.index = g_capture_mode;
 	if (ioctl(fd_v4l, VIDIOC_ENUM_FRAMESIZES, &frmsize) < 0) {
 		printf("get capture mode %d framesize failed\n", g_capture_mode);
-		return -1;
+		goto fail;
 	}
 
 	g_out_width = frmsize.discrete.width;
@@ -291,13 +293,13 @@ int v4l_capture_setup(void)
 	if (ioctl(fd_v4l, VIDIOC_S_FMT, &fmt) < 0)
 	{
 		printf("set format failed\n");
-		return -1;
+		goto fail;
 	}
 
 	if (ioctl(fd_v4l, VIDIOC_G_FMT, &fmt) < 0)
 	{
 		printf("get format failed\n");
-		return -1;
+		goto fail;
 	}
 
 	memset(&parm, 0, sizeof(parm));
@@ -315,6 +317,10 @@ int v4l_capture_setup(void)
 	g_frame_size = fmt.fmt.pix.sizeimage;
 
 	return fd_v4l;
+
+fail:
+	close(fd_v4l);
+	return -1;
 }
 
 void yuyvtorgb565(unsigned char *yuyv, unsigned char *dst )
@@ -395,17 +401,19 @@ int v4l_capture_test(int fd_v4l)
 	struct fb_var_screeninfo var;
 	struct v4l2_buffer buf;
 	char fb_device[100] = "/dev/fb0";
-	int fd_fb = 0;
+	int fd_fb = -1;
 	int frame_num = 0, fb0_size;
-	unsigned char *fb0;
+	unsigned char *fb0 = MAP_FAILED;
 	struct timeval tv1, tv2;
 	int j = 0;
 	int out_w = 0, out_h = 0;
 	int bufoffset;
 	FILE * fd_y_file = 0;
+	size_t wsize;
 	unsigned char *cscbuf = NULL;
+	int ret = -1;
 
-	if (g_saved_to_file == 1) {
+	if (g_saved_to_file) {
 		if ((fd_y_file = fopen(g_saved_filename, "wb")) == NULL) {
 			printf("Unable to create y frame recording file\n");
 			return -1;
@@ -444,18 +452,18 @@ int v4l_capture_test(int fd_v4l)
 
 	 /* Map the device to memory*/
 	fb0_size = var.xres * var.yres_virtual * var.bits_per_pixel / 8;
-	fb0 = (unsigned char *)mmap(0, fb0_size,
-					PROT_READ | PROT_WRITE, MAP_SHARED, fd_fb, 0);
-	if ((int)fb0 == -1) {
+	fb0 = (unsigned char *)mmap(0, fb0_size, PROT_READ | PROT_WRITE,
+				    MAP_SHARED, fd_fb, 0);
+	if (fb0 == MAP_FAILED) {
 		printf("Error: failed to map framebuffer device 0 to memory.\n");
 		goto FAIL;
 	}
 
 	/* allocate buffer for csc */
 	cscbuf = malloc(out_w * out_h * 2);
-    if (cscbuf == NULL) {
+	if (cscbuf == NULL) {
 		printf("Unable to allocate cssbuf bytes\n");
-        goto FAIL;
+		goto FAIL;
 	}
 
 	var.yoffset = var.yres;
@@ -476,9 +484,13 @@ loop:
 			break;
 		}
 
-		if (fd_y_file) {
+		if (g_saved_to_file) {
 			/* Save capture frame to file */
-			fwrite(buffers[buf.index].start, g_frame_size, 1, fd_y_file);
+			wsize = fwrite(buffers[buf.index].start, g_frame_size, 1, fd_y_file);
+			if (wsize < 1) {
+				printf("No space left on device. Stopping after %d frames.\n", frame_num);
+				break;
+			}
 		} else {
 			/* Show capture frame to display */
 			software_csc(buffers[buf.index].start, cscbuf, out_w, out_h);
@@ -517,15 +529,11 @@ loop:
 	} while((tv2.tv_sec - tv1.tv_sec < g_timeout) && !quitflag);
 
 	/* Make sure pan display offset is zero before capture is stopped */
-	if (g_saved_to_file == 0)
-		if (var.yoffset) {
-			var.yoffset = 0;
-			if (ioctl(fd_fb, FBIOPAN_DISPLAY, &var) < 0)
-				printf("FBIOPAN_DISPLAY failed\n");
-		}
-
-	if (fd_y_file)
-		fclose(fd_y_file);
+	if (!g_saved_to_file && var.yoffset) {
+		var.yoffset = 0;
+		if (ioctl(fd_fb, FBIOPAN_DISPLAY, &var) < 0)
+			printf("FBIOPAN_DISPLAY failed\n");
+	}
 
 	if (stop_capturing(fd_v4l) < 0)
 		printf("stop_capturing failed\n");
@@ -536,19 +544,20 @@ loop:
 		goto loop;
 	}
 
-	if (g_saved_to_file == 0) {
-		munmap((void *)fd_fb, fb0_size);
-		close(fd_fb);
-		free(cscbuf);
-	}
-
-	close(fd_v4l);
-	return 0;
+	ret = 0;
 FAIL:
-	if (g_saved_to_file == 0)
+	free(cscbuf);
+
+	if (fb0 != MAP_FAILED)
+		munmap(fb0, fb0_size);
+
+	if (fd_fb >= 0)
 		close(fd_fb);
-	close(fd_v4l);
-	return -1;
+
+	if (fd_y_file)
+		fclose(fd_y_file);
+
+	return ret;
 }
 
 void print_help(void)
@@ -598,7 +607,7 @@ int process_cmdline(int argc, char **argv)
 			g_mem_type = V4L2_MEMORY_USERPTR;
 #endif
 		} else if (strcmp(argv[i], "-l") == 0) {
-			vl42_device_cap_list();
+			v4l2_device_cap_list();
 			return -1;
 		} else {
 			print_help();
@@ -675,7 +684,7 @@ int memalloc(int buf_size, int buf_cnt)
 			goto err;
 		}
 		printf("%s, buf_size=0x%x\n", __func__, buf_size);
-		printf("USRP: alloc bufs va=0x%x, pa=0x%x, size %d\n",
+		printf("USRP: alloc bufs va=%p, pa=0x%x, size %d\n",
 				buffers[i].start, buffers[i].offset, buf_size);
 	}
 
@@ -693,6 +702,18 @@ int main(int argc, char **argv)
 {
 	int fd_v4l;
 	quitflag = 0;
+	int ret;
+	char *soc_list[] = {"i.MX6SLL", "i.MX6ULL", "i.MX6UL",
+			"i.MX7D", "i.MX6SX", "i.MX6SL", "i.MX8MQ",
+			"i.MX8MM", " "};
+
+	print_name(argv);
+
+	ret = soc_version_check(soc_list);
+	if (ret == 0) {
+		printf("mx6s_v4l2_capture.out not supported on current soc\n");
+		return 0;
+	}
 
 	pthread_t sigtid;
 	sigemptyset(&sigset);
@@ -716,9 +737,13 @@ int main(int argc, char **argv)
 
 	v4l_capture_test(fd_v4l);
 
+	close(fd_v4l);
+
 	if (g_mem_type == V4L2_MEMORY_USERPTR)
 		memfree(g_frame_size, TEST_BUFFER_NUM);
 
+	print_result(argv);
+
 	return 0;
 }
 
