@@ -46,6 +46,8 @@ extern "C"{
 #include <linux/mxc_v4l2.h>
 #include <linux/ipu.h>
 
+#include "../../include/test_utils.h"
+
 #define TFAIL -1
 #define TPASS 0
 
@@ -213,7 +215,7 @@ mxc_v4l_output_test(FILE *in)
 
 			buffers[i].length = buf.length;
 			buffers[i].offset = (size_t) buf.m.offset;
-			printf("VIDIOC_QUERYBUF: length = %d, offset = %d\n",
+			printf("VIDIOC_QUERYBUF: length = %d, offset = %zd\n",
 				buffers[i].length, buffers[i].offset);
 			buffers[i].start = mmap (NULL, buffers[i].length,
 					PROT_READ | PROT_WRITE, MAP_SHARED,
@@ -227,7 +229,7 @@ mxc_v4l_output_test(FILE *in)
 	}
 
         gettimeofday(&tv_start, 0);
-        printf("start time = %d s, %d us\n", tv_start.tv_sec, tv_start.tv_usec);
+        printf("start time = %ld s, %ld us\n", tv_start.tv_sec, tv_start.tv_usec);
 
         for (i = 0; ; i++) {
                 buf.type = V4L2_BUF_TYPE_VIDEO_OUTPUT;
@@ -426,7 +428,7 @@ int process_cmdline(int argc, char **argv)
                         if ( (g_in_fmt != V4L2_PIX_FMT_BGR24) &&
                              (g_in_fmt != V4L2_PIX_FMT_BGR32) &&
                              (g_in_fmt != V4L2_PIX_FMT_RGB565) &&
-                             (g_in_fmt != 'PMBW') &&
+                             (g_in_fmt != v4l2_fourcc('P', 'M', 'B', 'W')) &&
                              (g_in_fmt != V4L2_PIX_FMT_UYVY) &&
 			     (g_in_fmt != V4L2_PIX_FMT_YUYV) &&
 			     (g_in_fmt != V4L2_PIX_FMT_YUV422P) &&
@@ -439,7 +441,7 @@ int process_cmdline(int argc, char **argv)
                         {
                                 return -1;
                         }
-                        if (g_in_fmt == 'PMBW') {
+                        if (g_in_fmt == v4l2_fourcc('P', 'M', 'B', 'W')) {
                                 g_bmp_header = 1;
                                 g_in_fmt = V4L2_PIX_FMT_BGR24;
                         }
@@ -500,7 +502,7 @@ int memalloc(int buf_size, int buf_cnt)
 			ret = TFAIL;
 			goto err;
 		}
-		printf("USRP: alloc bufs offset 0x%x size %d\n", buffers[i].offset, buf_size);
+		printf("USRP: alloc bufs offset 0x%zx size %d\n", buffers[i].offset, buf_size);
 	}
 
 	return ret;
@@ -523,6 +525,8 @@ main(int argc, char **argv)
 	FILE * fd_in;
 	int retval = TPASS;
 
+    print_name(argv);
+
         if (process_cmdline(argc, argv) < 0) {
                 printf("MXC Video4Linux Output Device Test\n\n" \
                        "Syntax: mxc_v4l2_output.out\n -d <output display dev>\n" \
