@@ -1,17 +1,29 @@
 /*
  * Copyright 2004-2013, 2016 Freescale Semiconductor, Inc.
+ * Copyright 2017 NXP
  *
  * Copyright (c) 2006, Chips & Media.  All rights reserved.
  */
 
-/*
- * The code contained herein is licensed under the GNU General Public
- * License. You may obtain a copy of the GNU General Public License
- * Version 2 or later at the following locations:
- *
- * http://www.opensource.org/licenses/gpl-license.html
- * http://www.gnu.org/copyleft/gpl.html
- */
+/* 
+Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
+1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
+2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer 
+   in the documentation and/or other materials provided with the distribution.
+3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from 
+   this software without specific prior written permission.
+THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, 
+BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
+IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, 
+OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
+OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
+OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY 
+OF SUCH DAMAGE.THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE 
+WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
+HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+*/
+
 
 #include <sys/stat.h>
 #include <sys/time.h>
@@ -26,6 +38,7 @@
 #include "vpu_test.h"
 
 #include "../../include/soc_check.h"
+#include "../../include/test_utils.h"
 
 #define ONE_FRAME_INTERV 100000 // 100 ms
 
@@ -256,6 +269,8 @@ parse_main_args(int argc, char *argv[])
 {
 	int status = 0, opt;
 
+	print_name(argv);
+
 	do {
 		opt = getopt(argc, argv, mainopts);
 		switch (opt)
@@ -470,6 +485,9 @@ signal_thread(void *arg)
 		sigwait(&sigset, &sig);
 		if (sig == SIGINT) {
 			warn_msg("Ctrl-C received\n");
+		}
+		else if (sig == SIGTERM) {
+			//info_msg("normal termination signal received\n");
 		} else {
 			warn_msg("Unknown signal. Still exiting\n");
 		}
@@ -489,7 +507,7 @@ main(int argc, char *argv[])
 {
 	int err, nargc, i, ret;
 	char *pargv[32] = {0}, *dbg_env;
-	pthread_t sigtid;
+	pthread_t sigtid = 0;
 #ifdef COMMON_INIT
 	vpu_versioninfo ver;
 #endif
@@ -528,6 +546,7 @@ main(int argc, char *argv[])
 #ifndef _FSL_VTS_
 	sigemptyset(&sigset);
 	sigaddset(&sigset, SIGINT);
+	sigaddset(&sigset, SIGTERM);
 	pthread_sigmask(SIG_BLOCK, &sigset, NULL);
 	pthread_create(&sigtid, NULL, (void *)&signal_thread, NULL);
 #endif
@@ -641,6 +660,11 @@ main(int argc, char *argv[])
 		}
 	}
 
+	if (sigtid != 0) {
+		pthread_kill(sigtid, SIGTERM);
+		pthread_join(sigtid, (void *)&ret_thr);
+	}
+
 #ifdef COMMON_INIT
 	vpu_UnInit();
 #endif
