@@ -1,9 +1,10 @@
 /*
  * pxp_test - V4L2 test application for the PxP
  *
- * Copyright (C) 2009-2015 Freescale Semiconductor, Inc.
  * Copyright 2008-2009 Embedded Alley Solutions
  * Matt Porter <mporter@embeddedalley.com>
+ * Copyright (C) 2009-2016 Freescale Semiconductor, Inc.
+ * Copyright 2017 NXP
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,6 +44,8 @@
 
 #include "../../include/soc_check.h"
 
+#include "../../include/test_utils.h"
+
 #define MAX_V4L2_DEVICE_NR     64
 
 #define DEFAULT_WIDTH	320
@@ -185,7 +188,6 @@ int quitflag = 0;
 static int signal_thread(void *arg)
 {
 	int sig;
-	struct pxp_control *pxp = (struct pxp_control *)arg;
 
 	pthread_sigmask(SIG_BLOCK, &sigset, NULL);
 
@@ -841,7 +843,10 @@ int main(int argc, char **argv)
 	struct pxp_control *pxp;
 	pthread_t sigtid;
 	int ret;
-	char *soc_list[] = {"i.MX6UL", "i.MX7D", "i.MX6SX", "i.MX6SL", " "};
+	char *soc_list[] = {"i.MX6SLL", "i.MX6ULL", "i.MX6UL",
+				"i.MX7D", "i.MX6SX", "i.MX6SL", " "};
+
+	print_name(argv);
 
 	ret = soc_version_check(soc_list);
 	if (ret == 0) {
@@ -887,5 +892,7 @@ int main(int argc, char **argv)
 
 	pxp_cleanup(pxp);
 
+	print_result(argv);
+
 	return 0;
 }
